@@ -3,6 +3,7 @@
 https://docs.python.org/3/howto/logging-cookbook.html#use-of-alternative-formatting-styles
 """
 import logging
+from typing import Any, Optional
 
 
 class M:
@@ -12,7 +13,7 @@ class M:
     >>> logging.info(M('foo={foo}', foo=1))
     """
 
-    def __init__(self, fmt, *args, **kwargs):
+    def __init__(self, fmt: str, *args: Any, **kwargs: Any):
         self.fmt = fmt
         self.args = args
         self.kwargs = kwargs
@@ -25,7 +26,7 @@ class M:
 
 
 class StyleAdapter(logging.LoggerAdapter):
-    def __init__(self, logger, extra=None):
+    def __init__(self, logger: logging.Logger, extra: Optional[dict] = None):
         super(StyleAdapter, self).__init__(logger, extra or {})
 
     def log(self, level, msg, *args, **kwargs):
